Top

    Fee Stake: Mexico City
    Mexico City, Mexico
    December 8th 2007
    2R+F
    10 players
    Omael Rangel

    Deck Name: Nephandi
    Description:
    4 memories of mortality -- when they are gone i should add a fort. library, a pentex subversion and maybe anarchist troublemaker
    6 computer hacking -- maybe add 1 more
    3 glancing blows -- I'll remove this and add more concealed and molotovs
    1 .44 magnum -- this should be another grenade but i only had 7 at the time

    Crypt (12 cards, min=4, max=20, avg=3)
    --------------------------------------
    4x Antonio d'Erlette	5   THA dom for pot	Tremere antitribu:4
    4x Tupdog		1   POT VIS		Gargoyle:3
    2x Keith Moody		3   DOM			Tremere antitribu:4
    1x Ember Wright		3   aus dom		Tremere antitribu:3
    1x Saiz			3   aus dom		Tremere antitribu:3

    Library (86)
    Action [6]
    6x Computer Hacking

    Action Modifier [8]
    8x Empowering the Puppet King

    Ally [10]
    8x Nephandus (Mage)
    1x Ossian
    1x Vagabond Mystic

    Combat [14]
    8x Concealed Weapon
    3x Glancing Blow
    3x Molotov Cocktail

    Equipment [8]
    1x .44 Magnum
    7x Flash Grenade

    Event [2]
    2x Unmasking, The

    Master [22]
    1x Archon Investigation
    4x Blood Doll
    3x Direct Intervention
    2x Haven Uncovered
    1x Information Highway
    6x Life in the City
    4x Memories of Mortality
    1x Mob Connections

    Reaction [16]
    8x Deflection
    5x On the Qui Vive
    3x Wake with Evening's Freshness